pub struct AuthRequirement {
pub provider_id: String,
pub audiences: String,
}Expand description
User-defined authentication requirements, including support for JSON Web Token (JWT).
Fields
provider_id: String[id][google.api.AuthProvider.id] from authentication provider.
Example:
provider_id: bookstore_authaudiences: StringNOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.
The list of JWT audiences. that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, only JWTs with audience “https://\[Service_name\]\[google.api.Service.name\]/\[API_name\]\[google.protobuf.Api.name\]" will be accepted. For example, if no audiences are in the setting, LibraryService API will only accept JWTs with the following audience “https://library-example.googleapis.com/google.example.library.v1.LibraryService".
Example:
audiences: bookstore_android.apps.googleusercontent.com,
bookstore_web.apps.googleusercontent.comTrait Implementations
Sourceimpl Clone for AuthRequirement
impl Clone for AuthRequirement
Sourcefn clone(&self) -> AuthRequirement
fn clone(&self) -> AuthRequirement
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AuthRequirement
impl Debug for AuthRequirement
Sourceimpl Default for AuthRequirement
impl Default for AuthRequirement
Sourcefn default() -> AuthRequirement
fn default() -> AuthRequirement
Sourceimpl Hash for AuthRequirement
impl Hash for AuthRequirement
Sourceimpl Message for AuthRequirement
impl Message for AuthRequirement
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for AuthRequirement
impl PartialEq for AuthRequirement
Sourcefn eq(&self, other: &AuthRequirement) -> bool
fn eq(&self, other: &AuthRequirement) -> bool
self and other values to be equal, and is used by ==.