pub struct BatchingDescriptorProto {
pub batched_field: String,
pub discriminator_fields: Vec<String>,
pub subresponse_field: String,
}Expand description
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Fields
batched_field: StringThe repeated field in the request message to be aggregated by batching.
discriminator_fields: Vec<String>A list of the fields in the request message. Two requests will be batched
together only if the values of every field specified in
request_discriminator_fields is equal between the two requests.
subresponse_field: StringOptional. When present, indicates the field in the response message to be used to demultiplex the response into multiple response messages, in correspondence with the multiple request messages originally batched together.