pub struct UsageRule {
pub selector: String,
pub allow_unregistered_calls: bool,
pub skip_service_control: bool,
}Expand description
Usage configuration rules for the service.
Fields
selector: StringSelects the methods to which this rule applies. Use ‘*’ to indicate all methods in all APIs.
Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
allow_unregistered_calls: boolUse this rule to configure unregistered calls for the service. Unregistered calls are calls that do not contain consumer project identity. (Example: calls that do not contain an API key).
WARNING: By default, API methods do not allow unregistered calls, and each method call must be identified by a consumer project identity.
skip_service_control: boolIf true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available. This flag is used by Google Cloud Endpoints to bypass checks for internal methods, such as service health check methods.