OperationResponseMapping

Enum OperationResponseMapping 

#[repr(i32)]
pub enum OperationResponseMapping { Undefined = 0, Name = 1, Status = 2, ErrorCode = 3, ErrorMessage = 4, }
An enum to be used to mark the essential (for polling) fields in an API-specific Operation object. A custom Operation object may contain many different fields, but only few of them are essential to conduct a successful polling process.

Variants



Undefined = 0

Do not use.



Name = 1

A field in an API-specific (custom) Operation object which carries the same meaning as google.longrunning.Operation.name.



Status = 2

A field in an API-specific (custom) Operation object which carries the same meaning as google.longrunning.Operation.done. If the annotated field is of an enum type, annotated_field_name == EnumType.DONE semantics should be equivalent to Operation.done == true. If the annotated field is of type boolean, then it should follow the same semantics as Operation.done. Otherwise, a non-empty value should be treated as Operation.done == true.



ErrorCode = 3

A field in an API-specific (custom) Operation object which carries the same meaning as google.longrunning.Operation.error.code.



ErrorMessage = 4

A field in an API-specific (custom) Operation object which carries the same meaning as google.longrunning.Operation.error.message.

Implementations

Source

impl OperationResponseMapping

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of OperationResponseMapping.

pub fn from_i32(value: i32) -> Option<OperationResponseMapping>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a OperationResponseMapping, or None if value is not a valid variant.

Source

impl OperationResponseMapping

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.